
Timeseria docs
--------------

Docs are generated out from the code docstrings using Sphinx.

To build the docs, run the makedocs.sh script.

To re-generate autosummary-generated files (nearly all the *.rst files in this directory, change `autosummary_generate` to `True` in `config.py`. Watch out that the order will be re-set to alphabetical (see https://github.com/sphinx-doc/sphinx/issues/5379).


